/**********************************************************************
** Copyright (C) 2000 Trolltech AS.  All rights reserved.
**
** This file is part of Qt Designer.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
** See http://www.trolltech.com/gpl/ for GPL licensing information.
**
** Contact info@trolltech.com if any conditions of this licensing are
** not clear to you.
**
**********************************************************************/

#ifndef EDITOR_H
#define EDITOR_H

// This file has been slightly modified for Xplode

// Qt includes
#include <qtextedit.h>
#include <qfile.h>
#include <qapplication.h>
#include <qpopupmenu.h>
#include <qaccel.h>
#include <private/qrichtext_p.h>

// Forward class/struct declaration
struct Config;
class ParenMatcher;
class QAccel;

// Handles an text edit-window with syntax highlighting
class Editor : public QTextEdit
{
	Q_OBJECT

public:
	enum Selection
	{
		Error = 3,
		Step = 4
	};

	Editor(QWidget *parent, const char *name);
	QTextDocument *document() const { return QTextEdit::document(); }
	void placeCursor(const QPoint &p, QTextCursor *c) { QTextEdit::placeCursor(p, c); }
	void setDocument(QTextDocument *doc) { QTextEdit::setDocument(doc); }
	QTextCursor *textCursor() const { return QTextEdit::textCursor(); }
	void repaintChanged() { QTextEdit::repaintChanged(); }
	virtual void configChanged();
	Config *config() { return cfg; }
	virtual bool supportsErrors() const { return true; }
	virtual bool supportsBreakPoints() const { return true; }
	virtual void makeFunctionVisible(QTextParag *) {}
	void drawCursor(bool b) { QTextEdit::drawCursor(b); }
	bool eventFilter(QObject *o, QEvent *e);

signals:
	void clearErrorMarker();
	void intervalChanged();

private slots:
	void cursorPosChanged(QTextCursor *c);
	void doChangeInterval();

protected:
	ParenMatcher *parenMatcher;
	QString filename;
	Config *cfg;
	bool hasError;
};

#endif
